@@ -488,6 +488,7 @@ class CreateFlowByFilesRequest(AbstractModel):
 TEXT - 内容文本控件
 MULTI_LINE_TEXT - 多行文本控件
 CHECK_BOX - 勾选框控件
+ATTACHMENT - 附件
 注：默认字体大小为 字号12
         :type Components: list of Component
         :param Deadline: 签署流程的签署截止时间。
@@ -609,7 +610,10 @@ class CreateFlowRequest(AbstractModel):
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
         :param Agent: 应用相关信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
-        :param Unordered: 发送类型(true为无序签,false为顺序签)
+        :param Unordered: 发送类型：
+true：无序签
+false：有序签
+注：默认为false（有序签），请和模板中的配置保持一致
         :type Unordered: bool
         :param DeadLine: 签署流程的签署截止时间。
 值为unix时间戳,精确到秒,不传默认为当前时间一年后
@@ -891,7 +895,7 @@ class DescribeFileUrlsRequest(AbstractModel):
         :type Offset: int
         :param Limit: 指定资源数量，查询全部资源则传入-1
         :type Limit: int
-        :param UrlTtl: 下载url过期时间，单位秒。0: 按默认值5分钟，允许范围：1s~24*60*60s(1天)
+        :param UrlTtl: 下载url过期时间，单位秒。0: 按默认值5分钟，允许范围：1s~24x60x60s(1天)
         :type UrlTtl: int
         :param Scene: 暂不开放
         :type Scene: str
